This is a helper function that returns a list with three logical values:
wait, collect, and submit. There are four possible cases:
plan == "collect", then all three are TRUE.
plan == "wait", then all but collect are TRUE.
plan == "submit" then only submit equals TRUE.
plan == "none" then all three are FALSE.
In general, bot wait and submit will be passed to sbatch.
When collect == TRUE, then it usually means that the function will be calling
Slurm_collect right after submitting the job via sbatch.